@@ -16,7 +16,7 @@
 #include <QString>
 #include <QStringList>
 #include <QHash>
-#include <QVector>
+#include <QList>
 #include <QThread>
 #include <QStandardPaths>
 #include <QDir>
@@ -43,7 +43,7 @@ private Q_SLOTS:
     {
         qRegisterMetaType<QHash<qulonglong,int>>("QHash<qulonglong,int>");
         qRegisterMetaType<QHash<QString,QUrl>>("QHash<QString,QUrl>");
-        qRegisterMetaType<QVector<qlonglong>>("QVector<qlonglong>");
+        qRegisterMetaType<QList<qlonglong>>("QList<qlonglong>");
         qRegisterMetaType<QHash<qlonglong,int>>("QHash<qlonglong,int>");
         qRegisterMetaType<QList<QUrl>>("QList<QUrl>");
         Elisa::ElisaConfiguration::instance(QStringLiteral("scanAtStartupFeature"));
