@@ -364,86 +364,40 @@ void MediaPlayList::enqueueRestoredEntries(const QVariantList &newEntries)
     endInsertRows();
 }
 
-void MediaPlayList::enqueueFilesList(const DataTypes::EntryDataList &newEntries)
-{
-    qCDebug(orgKdeElisaPlayList()) << "MediaPlayList::enqueueFilesList";
-
-    beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size() + newEntries.size() - 1);
-    for (const auto &oneTrackUrl : newEntries) {
-        const auto &trackUrl = std::get<2>(oneTrackUrl);
-        auto newEntry = MediaPlayListEntry(trackUrl);
-        newEntry.mEntryType = ElisaUtils::FileName;
-        d->mData.push_back(newEntry);
-        if (trackUrl.isValid()) {
-            if (trackUrl.isLocalFile()) {
-                d->mTrackData.push_back({{DataTypes::ColumnsRoles::ResourceRole, trackUrl}});
-                auto entryString =  trackUrl.toLocalFile();
-                QFileInfo newTrackFile(entryString);
-                if (newTrackFile.exists()) {
-                    d->mData.last().mIsValid = true;
-                }
-            } else {
-                d->mTrackData.push_back({{DataTypes::ColumnsRoles::ResourceRole, trackUrl},
-                                         {DataTypes::ColumnsRoles::TitleRole, trackUrl.fileName()}});
-                d->mData.last().mIsValid = true;
-            }
-            Q_EMIT newUrlInList(trackUrl, newEntry.mEntryType);
-        } else {
-            d->mTrackData.push_back({});
-        }
-    }
-    endInsertRows();
-}
-
 void MediaPlayList::enqueueOneEntry(const DataTypes::EntryData &entryData)
 {
-    if (!std::get<0>(entryData).isEmpty() || !std::get<1>(entryData).isEmpty() || !std::get<2>(entryData).isEmpty()) {
-        beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size());
-        if (!std::get<0>(entryData).databaseId() && std::get<2>(entryData).isValid()) {
-            auto newEntry = MediaPlayListEntry{std::get<2>(entryData)};
-            newEntry.mEntryType = ElisaUtils::FileName;
-            d->mData.push_back(std::move(newEntry));
-            d->mTrackData.push_back({});
-        } else {
-            qCDebug(orgKdeElisaPlayList()) << "MediaPlayList::enqueueOneEntry" << std::get<0>(entryData) << std::get<1>(entryData) << std::get<0>(entryData).elementType();
-
-            d->mData.push_back(MediaPlayListEntry{std::get<0>(entryData).databaseId(), std::get<1>(entryData), std::get<0>(entryData).elementType()});
-            const auto &data = std::get<0>(entryData);
-            switch (data.elementType())
-            {
-            case ElisaUtils::Track:
-            case ElisaUtils::Radio:
-                d->mTrackData.push_back(static_cast<const DataTypes::TrackDataType&>(data));
-                break;
-            default:
-                d->mTrackData.push_back({});
-            }
-        }
-        if (std::get<2>(entryData).isValid()) {
-            Q_EMIT newUrlInList(std::get<2>(entryData), std::get<0>(entryData).elementType());
-        } else {
-            Q_EMIT newEntryInList(std::get<0>(entryData).databaseId(), std::get<1>(entryData), std::get<0>(entryData).elementType());
-        }
-        endInsertRows();
-    }
+    enqueueMultipleEntries({entryData});
 }
 
 void MediaPlayList::enqueueMultipleEntries(const DataTypes::EntryDataList &entriesData)
 {
     qCDebug(orgKdeElisaPlayList()) << "MediaPlayList::enqueueMultipleEntries" << entriesData.size();
 
-    beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size() + entriesData.size() - 1);
+    const int validEntries = std::accumulate(entriesData.cbegin(), entriesData.cend(), 0, [](const int validEntries, const auto &entryData) {
+        return entryData.isValid() ? validEntries + 1 : validEntries;
+    });
+
+    if (validEntries == 0) {
+        return;
+    }
+
+    beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size() + validEntries - 1);
     for (const auto &entryData : entriesData) {
-        qCDebug(orgKdeElisaPlayList()) << "MediaPlayList::enqueueMultipleEntries" << std::get<0>(entryData);
-        auto trackUrl = std::get<0>(entryData)[DataTypes::ResourceRole].toUrl();
-        if (!std::get<0>(entryData).databaseId() && trackUrl.isValid()) {
+        qCDebug(orgKdeElisaPlayList()) << "MediaPlayList::enqueueMultipleEntries" << entryData.musicData;
+
+        if (!entryData.isValid()) {
+            continue;
+        }
+
+        const auto trackUrl = entryData.url.isValid() ? entryData.url : entryData.musicData[DataTypes::ResourceRole].toUrl();
+        if (!entryData.musicData.databaseId() && trackUrl.isValid()) {
             auto newEntry = MediaPlayListEntry{trackUrl};
             newEntry.mEntryType = ElisaUtils::FileName;
             d->mData.push_back(std::move(newEntry));
             d->mTrackData.push_back({});
         } else {
-            d->mData.push_back(MediaPlayListEntry{std::get<0>(entryData).databaseId(), std::get<1>(entryData), std::get<0>(entryData).elementType()});
-            const auto &data = std::get<0>(entryData);
+            d->mData.push_back(MediaPlayListEntry{entryData.musicData.databaseId(), entryData.title, entryData.musicData.elementType()});
+            const auto &data = entryData.musicData;
             switch (data.elementType())
             {
             case ElisaUtils::Track:
@@ -458,10 +412,10 @@ void MediaPlayList::enqueueMultipleEntries(const DataTypes::EntryDataList &entri
 
         if (trackUrl.isValid()) {
             qCDebug(orgKdeElisaPlayList()) << "MediaPlayList::enqueueMultipleEntries" << "new url" << trackUrl
-                                           << std::get<0>(entryData).elementType();
-            Q_EMIT newUrlInList(trackUrl, std::get<0>(entryData).elementType());
+                                           << entryData.musicData.hasElementType() << entryData.musicData.elementType();
+            Q_EMIT newUrlInList(trackUrl, entryData.musicData.hasElementType() ? entryData.musicData.elementType() : ElisaUtils::FileName);
         } else {
-            Q_EMIT newEntryInList(std::get<0>(entryData).databaseId(), std::get<1>(entryData), std::get<0>(entryData).elementType());
+            Q_EMIT newEntryInList(entryData.musicData.databaseId(), entryData.title, entryData.musicData.elementType());
         }
     }
     endInsertRows();
