@@ -7,8 +7,6 @@
 #include "trackslistener.h"
 
 #include "playListLogging.h"
-#include "databaseinterface.h"
-#include "datatypes.h"
 #include "filescanner.h"
 #include "filewriter.h"
 
@@ -56,7 +54,7 @@ void TracksListener::tracksAdded(const ListTrackDataType &allTracks)
             return;
         }
 
-        for (auto itTrack = d->mTracksByNameSet.begin(); itTrack != d->mTracksByNameSet.end(); ) {
+        for (auto itTrack = d->mTracksByNameSet.cbegin(); itTrack != d->mTracksByNameSet.cend(); ) {
             if (!std::get<0>(*itTrack).isEmpty() && std::get<0>(*itTrack) != oneTrack.title()) {
                 ++itTrack;
                 continue;
@@ -226,6 +224,7 @@ void TracksListener::newEntryInList(qulonglong newDatabaseId,
     case ElisaUtils::Composer:
     case ElisaUtils::Unknown:
     case ElisaUtils::Container:
+    case ElisaUtils::PlayList:
         break;
     }
 }
@@ -277,6 +276,7 @@ void TracksListener::newUrlInList(const QUrl &entryUrl, ElisaUtils::PlayListEntr
     case ElisaUtils::Genre:
     case ElisaUtils::Unknown:
     case ElisaUtils::Container:
+    case ElisaUtils::PlayList:
         break;
     }
 }
